.. _index:


.. image:: logo/PyJibe_bw.png

|

PyJibe is a user interface for data analysis in atomic force
microscopy (AFM) with an emphasis on biological specimens, such
as tissue sections or single cells.
This is the documentation of PyJibe version |release|.

.. rtd_pdf::

Documentation
=============

.. toctree::
   :maxdepth: 2

   sec_getting_started
   sec_interface
   sec_tutorials
   sec_quick_guides

.. toctree::
   :maxdepth: 1

   sec_code_signing
   sec_changelog
   z_bib


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
